# Wrapper for Google API Client Library

Wrapper for Google API Client Library

## 準備

1. Google Drive API のドキュメントの[環境をセットアップする](https://developers.google.com/drive/api/quickstart/python?hl=ja#set_up_your_environment)に記載された以下の項目に記載された内容を実施する。

    - [API の有効化](https://developers.google.com/drive/api/quickstart/python?hl=ja#enable_the_api)
    - [OAuth 同意画面を構成する](https://developers.google.com/drive/api/quickstart/python?hl=ja#configure_the_oauth_consent_screen)
    - [デスクトップ アプリケーションの認証情報を承認する](https://developers.google.com/drive/api/quickstart/python?hl=ja#authorize_credentials_for_a_desktop_application)

2. 「デスクトップ アプリケーションの認証情報を承認する」の手順でダウンロードした `credentials.json` を以下のディレクトリに配置する。

    ```plaintext
    <PATH_TO_YOUR_PROJECT_ROOT>/secrets
    ```
